@@ -5,9 +5,13 @@ from djcelery_email.tasks import send_email
 
 
 class CeleryEmailBackend(BaseEmailBackend):
+    def __init__(self, fail_silently=False, **kwargs):
+        super(CeleryEmailBackend, self).__init__(fail_silently)
+        self.init_kwargs = kwargs
 
     def send_messages(self, email_messages, **kwargs):
         results = []
+        kwargs['_backend_init_kwargs'] = self.init_kwargs
         for msg in email_messages:
             results.append(send_email.delay(msg, **kwargs))
         return results
