@@ -17,7 +17,8 @@ TASK_CONFIG.update(CONFIG)
 @task(**TASK_CONFIG)
 def send_email(message, **kwargs):
     logger = send_email.get_logger()
-    conn = get_connection(backend=BACKEND)
+    conn = get_connection(backend=BACKEND,
+                          **kwargs.pop('_backend_init_kwargs', {}))
     try:
         result = conn.send_messages([message])
         logger.debug("Successfully sent email message to %r.", message.to)
